package tourplaner.business;

import javax.imageio.ImageIO;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.awt.image.RenderedImage;
import java.io.File;
import java.io.IOException;

public class DirectionMap {

    private double dauer, strecke;
    private String start, end, tourname, file, filepdf;
    private Image map, mappdf;

    /**
     * Holt die Map als image und alle Daten zur berechneten Route
     *
     * @param start Startpunkt
     * @param ende Endpunkt
     * @param tourname Name der Aktuellen Tour
     * @throws IOException Fehler beim Image der Map
     */
    public DirectionMap (String start, String ende, String tourname) throws IOException {
        this.map = getMap(start, ende, ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "map", "size"));
        this.mappdf = getMap(start, ende, ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "map", "sizePdf"));
        this.start = start;
        this.end = ende;
        this.tourname = tourname;
        this.file = ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "map", "path") + this.tourname + ".jpg";
        this.filepdf = ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "map", "path") + this.tourname + "_pdf.jpg";
        FileHelper.saveImage(this.map, "jpg", new File(this.file));
        FileHelper.saveImage(this.mappdf, "jpg", new File(this.filepdf));
        FileHelper.openDefault(file);
    }

    /**
     * Downloadet die Map von Mapquest
     * @param start Startpunkt
     * @param ende Endpunkt
     * @return Image von der Map
     * @throws IOException Fehler beim Get der Map
     */
    private Image getMap(String start, String ende, String size) throws IOException {
        return HttpHelper.httpGetImage("https://www.mapquestapi.com/staticmap/v5/map?start="+start+"&end="+ende+"&size="+size+"&key="+ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "map", "key"));
    }




}
