package tourplaner.business;

import com.itextpdf.text.*;
import com.itextpdf.text.Font;
import com.itextpdf.text.Image;
import com.sun.scenario.effect.ImageData;
import tourplaner.object.Log;
import tourplaner.object.Tour;


import com.itextpdf.text.pdf.PdfPCell;
import com.itextpdf.text.pdf.PdfPTable;
import com.itextpdf.text.pdf.PdfWriter;

import java.awt.*;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Date;

/**
 * https://github.com/ymasory/iText-4.2.0
 */
public class Reporter {

    private static Font catFont = new Font(Font.TIMES_ROMAN, 18,
            Font.BOLD);
    private static Font redFont = new Font(Font.TIMES_ROMAN, 12,
            Font.NORMAL, Color.RED);
    private static Font subFont = new Font(Font.TIMES_ROMAN, 16,
            Font.BOLD);
    private static Font smallBold = new Font(Font.TIMES_ROMAN, 12,
            Font.BOLD);

    public static void createTourReport(String tourname)   {
        Tour tour = TourPlaner.getTour(tourname);
        tour.setLog(TourPlaner.getLogs(tourname));
        String file = ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "report", "path") + tourname+".pdf";
        try {
            Document document = new Document();
            PdfWriter.getInstance(document, new FileOutputStream(file));
            document.open();
            addMetaData(document, tour);
//            addTitlePage(document, tour);
            addContent(document, tour);
            document.close();
        } catch (DocumentException | FileNotFoundException e) {
            LogHelper.error(e.getMessage(), e.getClass().getName());
        }
        FileHelper.openDefault(file);
    }

    // iText allows to add metadata to the PDF which can be viewed in your Adobe
    // Reader
    // under File -> Properties
    private static void addMetaData(Document document, Tour tour) {
        document.addTitle("Tour Report -> " + tour.getName());
        document.addSubject("Tourplaner by DerGeorg");
        document.addKeywords("Tourplaner, Tour, Report");
        document.addAuthor("Tourplaner");
        document.addCreator("Tourplaner");
    }

    private static void addContent(Document document, Tour tour) throws DocumentException {
        Anchor anchor = new Anchor("Tour Report von -> " + tour.getName(), catFont);
        anchor.setName("Tour Report von -> " + tour.getName());

        // Second parameter is the number of the chapter
        Chapter catPart = new Chapter(new Paragraph(anchor), 1);

        Paragraph subPara = new Paragraph("Tour", subFont);
        Section subCatPart = catPart.addSection(subPara);
        subCatPart.add(new Paragraph("Report erstellt von: " + System.getProperty("user.name") + ", " + new Date()));
        subCatPart.add(new Paragraph("Startpunkt der Tour: " + tour.getStart()));
        subCatPart.add(new Paragraph("Zielpunkt der Tour: " + tour.getZiel()));
        subCatPart.add(new Paragraph("Berechnete Dauer der Tour: " + tour.getDauer()));
        subCatPart.add(new Paragraph("Berechnete Strecke der Tour: " + tour.getStrecke()));
        Paragraph emptyLine = new Paragraph();
        addEmptyLine(emptyLine, 5);
        subCatPart.add(emptyLine);


        // now add all this to the document
        document.add(catPart);

        Image image1 = null;
        try {
            image1 = Image.getInstance(TourPlaner.getImagePdfPath(tour.getName()));
            image1.setAlignment(Element.ALIGN_CENTER);
            image1.scaleAbsolute(600, 400);

            document.add(image1);
        } catch (IOException e) {
            LogHelper.error(e);
        }
        ArrayList<Log> logs = tour.getLogs();
        // Second parameter is the number of the chapter
        anchor = new Anchor("Logs", catFont);
        anchor.setName("Logs");
        catPart = new Chapter(new Paragraph(anchor), 2);
        catPart.add(new Paragraph("Anzahl der Logeinträge: " + logs.size()));

        for (Log log: logs) {
            subPara = new Paragraph("Log vom: " + log.getDatum() , subFont);
            subCatPart = catPart.addSection(subPara);
            subCatPart.add(new Paragraph("Dauer: " + log.getDauer()));
            subCatPart.add(new Paragraph("Davon Pause: " + log.getPause()));
            subCatPart.add(new Paragraph("Davon gegangen: " + log.getGegangen()));
            subCatPart.add(new Paragraph("Berechnete Durchschnittliche Geschwindigkeit: " + log.getAvgspeed()));
            subCatPart.add(new Paragraph("Entfernung: " + log.getStrecke()));
            subCatPart.add(new Paragraph("Höhenmeter: " + log.getHightmeter()));
            subCatPart.add(new Paragraph("Bemerkung: " + log.getBemerkung()));
        }
        // now add all this to the document
        document.add(catPart);
    }

    private static void createTable(Section subCatPart)
            throws BadElementException {
        PdfPTable table = new PdfPTable(5);

        // t.setBorderColor(BaseColor.GRAY);
        // t.setPadding(4);
        // t.setSpacing(4);
        // t.setBorderWidth(1);

        PdfPCell c1 = new PdfPCell(new Phrase("NR"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);

        c1 = new PdfPCell(new Phrase("Datum"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);

        c1 = new PdfPCell(new Phrase("Entfernung"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);

        c1 = new PdfPCell(new Phrase("Höhenmeter"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);

        c1 = new PdfPCell(new Phrase("AVG Geschwindigkeit"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);


        table.setHeaderRows(1);

        table.addCell("1.0");
        table.addCell("1.1");
        table.addCell("1.2");
        table.addCell("1.3");
        table.addCell("1.4");
        table.addCell("1.5");

        table.addCell("2.0");
        table.addCell("2.1");
        table.addCell("2.2");
        table.addCell("2.3");
        table.addCell("2.4");
        table.addCell("2.5");

        subCatPart.add(table);

    }
    private static void createTable2(Section subCatPart)
            throws BadElementException {
        PdfPTable table = new PdfPTable(5);

        // t.setBorderColor(BaseColor.GRAY);
        // t.setPadding(4);
        // t.setSpacing(4);
        // t.setBorderWidth(1);

        PdfPCell c1 = new PdfPCell(new Phrase("NR"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);

        c1 = new PdfPCell(new Phrase("Dauer"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);

        c1 = new PdfPCell(new Phrase("Davon Gegangen"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);

        c1 = new PdfPCell(new Phrase("Davon Pause"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);

        c1 = new PdfPCell(new Phrase("Bemerkung"));
        c1.setHorizontalAlignment(Element.ALIGN_CENTER);
        table.addCell(c1);


        table.setHeaderRows(1);

        table.addCell("1.0");
        table.addCell("1.1");
        table.addCell("1.2");
        table.addCell("1.3");
        table.addCell("1.4");
        table.addCell("1.5");

        table.addCell("2.0");
        table.addCell("2.1");
        table.addCell("2.2");
        table.addCell("2.3");
        table.addCell("2.4");
        table.addCell("2.5");

        subCatPart.add(table);
    }

    private static void addEmptyLine(Paragraph paragraph, int number) {
        for (int i = 0; i < number; i++) {
            paragraph.add(new Paragraph(" "));
        }
    }
}
