package tourplaner.business;

import org.apache.log4j.Logger;
import tourplaner.data.DbConnect;
import tourplaner.object.Log;
import tourplaner.object.Tour;

import java.awt.*;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;

/**
 * Haupt Logik des Tourplaners
 */
public class TourPlaner{
    private Logger logger;

    /**
     * Erstellt alle DB Tabellen falls nötig
     */
    public static void init(){
        new DbConnect().init();
    }

    /**
     * Holt alle touren aus der DB 
     * @return Alle touren als ArrayList
     */
    public static ArrayList<Tour> getAllTours(){
        return new DbConnect().getAllTouren();
    }

    /**
     * Bearbeitet eine Tour
     * @param oldname Alter Tourname
     * @param tour Neuer Tourname
     * @return false bei error
     */
    public static boolean editTour(String oldname, Tour tour) throws IOException {
        FileHelper.delFile(new File(getImagePath(oldname)));
        FileHelper.delFile(new File(getImagePdfPath(oldname)));
        new DirectionMap(tour.getStart(), tour.getZiel(), tour.getName());
        return new DbConnect().editTour(oldname, tour);
    }

    public static boolean delTour(String tourname){
        FileHelper.delFile(new File(getImagePath(tourname)));
        FileHelper.delFile(new File(getImagePdfPath(tourname)));
        return new DbConnect().delTour(tourname);
    }
    /**
     * Fügt eine Tour hinzu
     * @param newTour Neue Tour
     * @return false bei error
     */
    public static boolean addTour(Tour newTour) throws IOException {
        new DirectionMap(newTour.getStart(), newTour.getZiel(), newTour.getName());
        return new DbConnect().addTour(newTour);
    }

    public static Image getImage(String tourname) throws IOException {
        return FileHelper.getImage(new File(getImagePath(tourname)));
    }

    public static String getImagePath(String tourname){
        return ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "map", "path") + tourname + ".jpg";
    }
    public static String getImagePdfPath(String tourname){
        return ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "map", "path") + tourname + "_pdf.jpg";
    }

    public static void openImage(String tourname){
        FileHelper.openDefault(getImagePath(tourname));
    }


    public static ArrayList<Log> getLogs(String tourname){
        return new DbConnect().getLogs(tourname);
    }

    public static void doReport(String tourname){
        Reporter.createTourReport(tourname);
    }

    public static Tour getTour(String tourname){
        return new DbConnect().getTour(tourname);
    }

    public static boolean addLog(String tourname, Log log){
        if(Double.isInfinite(log.getAvgspeed())) log.setAvgspeed(-1.0);
        return new DbConnect().addLog(tourname, log);
    }

    public static boolean delLog(String tourname, String id){
        return new DbConnect().delLog(tourname, id);
    }

    public static boolean editLog(String tourname, Log log){
        if(Double.isInfinite(log.getAvgspeed())) log.setAvgspeed(-1.0);
        return new DbConnect().editLog(tourname, log);
    }


    public static String getMapJson(String start, String ziel){
        // TODO: 14.04.2021 Map Quest
        return start + " " + ziel;
    }
}
